Documentation
¶
Overview ¶
Copyright 2021 Absa Group Limited
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Generated by GoLic, for more details see: https://github.com/AbsaOSS/golic
Copyright 2021 Absa Group Limited ¶
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Generated by GoLic, for more details see: https://github.com/AbsaOSS/golic
package provides cobra commands
Copyright 2021 Absa Group Limited ¶
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Generated by GoLic, for more details see: https://github.com/AbsaOSS/golic
Copyright 2021 Absa Group Limited ¶
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Generated by GoLic, for more details see: https://github.com/AbsaOSS/golic
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Verbose bool
Functions ¶
Types ¶
type ServiceRunner ¶
type ServiceRunner struct {
// contains filtered or unexported fields
}
func Command ¶
func Command(service Service) *ServiceRunner
func (*ServiceRunner) MustRun ¶
func (r *ServiceRunner) MustRun() int
Run service once and panics if service is broken