inject

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 9, 2021 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Overview

Copyright 2021 ABSA Group Limited

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Generated by GoLic, for more details see: https://github.com/AbsaOSS/golic

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Generated by GoLic, for more details see: https://github.com/AbsaOSS/golic

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Generated by GoLic, for more details see: https://github.com/AbsaOSS/golic

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	Golic struct {
		Licenses map[string]string `yaml:"licenses"`
		Rules    map[string]struct {
			Prefix string   `yaml:"prefix"`
			Suffix string   `yaml:"suffix"`
			Under  []string `yaml:"under"`
		} `yaml:"rules"`
	} `yaml:"golic"`
}

func (*Config) IsWrapped

func (c *Config) IsWrapped(key string) bool

func (*Config) LicenseStartsAfterHeader

func (c *Config) LicenseStartsAfterHeader(key string) bool

type Inject

type Inject struct {
	// contains filtered or unexported fields
}

func New

func New(ctx context.Context, options Options) *Inject

func (*Inject) Run

func (i *Inject) Run() (err error)

func (*Inject) String

func (i *Inject) String() string

type Options

type Options struct {
	LicIgnore string
	Copyright string
	Dry       bool
	ConfigURL string
	Template  string
}

Jump to